# Ark-Bot

## Install the Executable
#### AMD Computers
To run this make sure you have python 3.10 installed and run this executable:
```
Ark-Driver/pywin32-304.win-amd64-py3.10.exe
```
#### Intel Computers
To run this make sure you have python 3.9 installed and run this executable:
```
Ark-Driver/pywin32-304.win32-py3.9.exe
```

## Choosing a terminal
Pick which terminal you'll be running the bot:

- [Linux Terminal](#linux-terminal)
- [Window Terminal](#windows-terminal)


## Linux Terminal
Install the arkdriver.
```shell
pip3 install arkdriver
```

Run your python environment.
```shell
python3
```

In your python environment enter the following:
```python
from arkdriver import run
run()
```

You're running the bot now. Now go to the [Final Steps](#final-steps)

## Windows Terminal
Install the arkdriver.
```shell
pip install arkdriver
```

Run your python environment.
```shell
python
```

In your python environment enter the following:
```python
from arkdriver import run
run()
```

You're running the bot now. Now go to the [Final Steps](#final-steps)

## Final Steps
Hop into your server and activate GCM (aka Admin mode). 
Go into the Ark-API and submit a command. The bot should
have received the command if done correctly.